.. _future-updates-link:

Future updates
**************

.. toctree::
   :maxdepth: 4
   :hidden:

Models
======
- Chung and Everhart :cite:`Chung1974`
- Dionne :cite:`Dionne1973,Dionne1975`
- Dionne 3D :cite:`Placais2020`
- Furman et Pivi :cite:`Furman2002,Furman2013`
- SLAB model :cite:`Jablonski1984`
- OKGM model :cite:`Jablonski2014`

Utility
=======
- N. Fil criterions :cite:`Fil2016a,Fil2020`.
- Configuration with a `TOML`.

Docs
====
- Remove complete module path in API.

.. versionadded:: 0.0.7
